@@ -14,14 +14,17 @@
 * $Id$
 *
 ***********************************************************************/
-static char const RCSID[] =
-"$Id$";
-
 #define _GNU_SOURCE 1 /* For SA_RESTART */
+#include "config.h"
 
-#include "relay.h"
-
+#include <sys/socket.h>
+#if defined(HAVE_LINUX_IF_H)
+#include <linux/if.h>
+#elif defined(HAVE_NET_IF_H)
+#include <net/if.h>
+#endif
 #include <signal.h>
+#include "relay.h"
 
 #ifdef HAVE_SYSLOG_H
 #include <syslog.h>
@@ -1107,9 +1110,9 @@ relayHandlePADO(PPPoEInterface const *iface,
     acIndex = iface - Interfaces;
 
     /* Source address must be unicast */
-    if (NOT_UNICAST(packet->ethHdr.h_source)) {
+    if (BROADCAST(packet->ethHdr.h_source)) {
 	syslog(LOG_ERR,
-	       "PADO packet from %02x:%02x:%02x:%02x:%02x:%02x on interface %s not from a unicast address",
+	       "PADO packet from %02x:%02x:%02x:%02x:%02x:%02x on interface %s from a broadcast address",
 	       packet->ethHdr.h_source[0],
 	       packet->ethHdr.h_source[1],
 	       packet->ethHdr.h_source[2],
